@@ -1,5 +1,5 @@
 package App::JESP;
-$App::JESP::VERSION = '0.010';
+$App::JESP::VERSION = '0.011';
 use Moose;
 
 use App::JESP::Plan;
@@ -303,7 +303,8 @@ a json datastructure like this:
     "patches": [
         { "id":"foobartable", "sql": "CREATE TABLE foobar(id INT PRIMARY KEY)"},
         { "id":"foobar_more", "file": "patches/morefoobar.sql" }
-        { "id":"foobar_abs",  "file": "/absolute/path/to/patches/evenmore.sql" }
+        { "id":"foobar_abs",  "file": "/absolute/path/to/patches/evenmore.sql" },
+        { "id":"a_backfill_script", "file": "path/to/executable/file.sh" }
     ]
   }
 
@@ -313,6 +314,52 @@ itself containing the SQL.
 
 You are encouraged to look in L<https://github.com/jeteve/App-JESP/tree/master/t> for examples.
 
+=head1 PATCH TYPES
+
+=head1 sql
+
+Simply add the SQL statement to execute in your patch structure:
+
+  {
+    "patches": [
+        ...
+        { "id":"foobartable", "sql": "CREATE TABLE foobar(id INT PRIMARY KEY)"}
+        ...
+  }
+
+This is convenient for very short SQL statment.
+
+=head1 sql files
+
+Point to a file that contains SQL statement(s) to be executed. The filename can be either absolute
+or relative to the directory that contains the plan.
+
+  {
+    "patches": [
+         ...
+        { "id":"foobar_more", "file": "patches/morefoobar.sql" }
+        { "id":"foobar_abs",  "file": "/absolute/path/to/patches/evenmore.sql" },
+         ...
+    ]
+  }
+
+The directory structure is free, but of course you are encouraged to keep it clean.
+
+=head1 script files (Unix only)
+
+Point to an EXECUTABLE file. (absolute or relative to the plan directory):
+
+  {
+    "patches": [
+        ...
+        { "id":"a_backfill_script", "file": "path/to/executable/file.sh" }
+        ...
+    ]
+  }
+
+See L<APP::JESP::Driver#apply_script> to see what environment the script is ran in. Note that the script
+needs to be executable by the current user to be detected as a script.
+
 =head1 COMPATIBILITY
 
 Compatibility of the meta-schema with SQLite, MySQL and PostgreSQL is guaranteed through automated testing.
